==> config-api-0.3.18-sources.jar: org/wildfly/swarm/config/messaging/activemq/server/LargeMessagesDirectoryPath.java <==
package org.wildfly.swarm.config.messaging.activemq.server;

import org.wildfly.swarm.config.runtime.Address;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.Implicit;
import java.beans.PropertyChangeSupport;
import java.beans.PropertyChangeListener;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
/**
 * A filesystem path pointing to one of the locations where ActiveMQ stores
 * persistent data.
 */
@Address("/subsystem=messaging-activemq/server=*/path=large-messages-directory")
@ResourceType("path")
@Implicit
public class LargeMessagesDirectoryPath<T extends LargeMessagesDirectoryPath<T>> {

	private String key;
	private PropertyChangeSupport pcs;
	private String path;
	private String relativeTo;

	public LargeMessagesDirectoryPath() {
		this.key = "large-messages-directory";
		this.pcs = new PropertyChangeSupport(this);
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * Adds a property change listener
	 */
	public void addPropertyChangeListener(PropertyChangeListener listener) {
		if (null == this.pcs)
			this.pcs = new PropertyChangeSupport(this);
		this.pcs.addPropertyChangeListener(listener);
	}

	/**
	 * Removes a property change listener
	 */
	public void removePropertyChangeListener(PropertyChangeListener listener) {
		if (this.pcs != null)
			this.pcs.removePropertyChangeListener(listener);
	}

	/**
	 * The actual filesystem path. Treated as an absolute path, unless the
	 * 'relative-to' attribute is specified, in which case the value is treated
	 * as relative to that path.
	 * <p>
	 * If treated as an absolute path, the actual runtime pathname specified by
	 * the value of this attribute will be determined as follows:
	 * </p>
	 * If this value is already absolute, then the value is directly used.
	 * Otherwise the runtime pathname is resolved in a system-dependent way. On
	 * UNIX systems, a relative pathname is made absolute by resolving it
	 * against the current user directory. On Microsoft Windows systems, a
	 * relative pathname is made absolute by resolving it against the current
	 * directory of the drive named by the pathname, if any; if not, it is
	 * resolved against the current user directory.
	 */
	@ModelNodeBinding(detypedName = "path")
	public String path() {
		return this.path;
	}

	/**
	 * The actual filesystem path. Treated as an absolute path, unless the
	 * 'relative-to' attribute is specified, in which case the value is treated
	 * as relative to that path.
	 * <p>
	 * If treated as an absolute path, the actual runtime pathname specified by
	 * the value of this attribute will be determined as follows:
	 * </p>
	 * If this value is already absolute, then the value is directly used.
	 * Otherwise the runtime pathname is resolved in a system-dependent way. On
	 * UNIX systems, a relative pathname is made absolute by resolving it
	 * against the current user directory. On Microsoft Windows systems, a
	 * relative pathname is made absolute by resolving it against the current
	 * directory of the drive named by the pathname, if any; if not, it is
	 * resolved against the current user directory.
	 */
	@SuppressWarnings("unchecked")
	public T path(String value) {
		Object oldValue = this.path;
		this.path = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("path", oldValue, value);
		return (T) this;
	}

	/**
	 * The name of another previously named path, or of one of the standard
	 * paths provided by the system. If 'relative-to' is provided, the value of
	 * the 'path' attribute is treated as relative to the path specified by this
	 * attribute. The standard paths provided by the system include:
	 * <ul>
	 * <li>jboss.home - the root directory of the JBoss AS distribution</li>
	 * <li>user.home - user's home directory</li>
	 * <li>user.dir - user's current working directory</li>
	 * <li>java.home - java installation directory</li>
	 * <li>jboss.server.base.dir - root directory for an individual server
	 * instance</li>
	 * <li>jboss.server.data.dir - directory the server will use for persistent
	 * data file storage</li>
	 * <li>jboss.server.log.dir - directory the server will use for log file
	 * storage</li>
	 * <li>jboss.server.tmp.dir - directory the server will use for temporary
	 * file storage</li>
	 * <li>jboss.domain.servers.dir - directory under which a host controller
	 * will create the working area for individual server instances</li>
	 * </ul>
	 */
	@ModelNodeBinding(detypedName = "relative-to")
	public String relativeTo() {
		return this.relativeTo;
	}

	/**
	 * The name of another previously named path, or of one of the standard
	 * paths provided by the system. If 'relative-to' is provided, the value of
	 * the 'path' attribute is treated as relative to the path specified by this
	 * attribute. The standard paths provided by the system include:
	 * <ul>
	 * <li>jboss.home - the root directory of the JBoss AS distribution</li>
	 * <li>user.home - user's home directory</li>
	 * <li>user.dir - user's current working directory</li>
	 * <li>java.home - java installation directory</li>
	 * <li>jboss.server.base.dir - root directory for an individual server
	 * instance</li>
	 * <li>jboss.server.data.dir - directory the server will use for persistent
	 * data file storage</li>
	 * <li>jboss.server.log.dir - directory the server will use for log file
	 * storage</li>
	 * <li>jboss.server.tmp.dir - directory the server will use for temporary
	 * file storage</li>
	 * <li>jboss.domain.servers.dir - directory under which a host controller
	 * will create the working area for individual server instances</li>
	 * </ul>
	 */
	@SuppressWarnings("unchecked")
	public T relativeTo(String value) {
		Object oldValue = this.relativeTo;
		this.relativeTo = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("relativeTo", oldValue, value);
		return (T) this;
	}
}

==> config-api-0.4.3-sources.jar: org/wildfly/swarm/config/messaging/activemq/server/LargeMessagesDirectoryPath.java <==
package org.wildfly.swarm.config.messaging.activemq.server;

import org.wildfly.swarm.config.runtime.Address;
import java.util.HashMap;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.Implicit;
import java.beans.PropertyChangeSupport;
import java.beans.PropertyChangeListener;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
/**
 * A filesystem path pointing to one of the locations where ActiveMQ stores
 * persistent data.
 */
@Address("/subsystem=messaging-activemq/server=*/path=large-messages-directory")
@ResourceType("path")
@Implicit
public class LargeMessagesDirectoryPath<T extends LargeMessagesDirectoryPath<T>>
		extends
			HashMap {

	private String key;
	private PropertyChangeSupport pcs;
	private String path;
	private String relativeTo;

	public LargeMessagesDirectoryPath() {
		super();
		this.key = "large-messages-directory";
		this.pcs = new PropertyChangeSupport(this);
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * Adds a property change listener
	 */
	public void addPropertyChangeListener(PropertyChangeListener listener) {
		if (null == this.pcs)
			this.pcs = new PropertyChangeSupport(this);
		this.pcs.addPropertyChangeListener(listener);
	}

	/**
	 * Removes a property change listener
	 */
	public void removePropertyChangeListener(PropertyChangeListener listener) {
		if (this.pcs != null)
			this.pcs.removePropertyChangeListener(listener);
	}

	/**
	 * The actual filesystem path. Treated as an absolute path, unless the
	 * 'relative-to' attribute is specified, in which case the value is treated
	 * as relative to that path.
	 * <p>
	 * If treated as an absolute path, the actual runtime pathname specified by
	 * the value of this attribute will be determined as follows:
	 * </p>
	 * If this value is already absolute, then the value is directly used.
	 * Otherwise the runtime pathname is resolved in a system-dependent way. On
	 * UNIX systems, a relative pathname is made absolute by resolving it
	 * against the current user directory. On Microsoft Windows systems, a
	 * relative pathname is made absolute by resolving it against the current
	 * directory of the drive named by the pathname, if any; if not, it is
	 * resolved against the current user directory.
	 */
	@ModelNodeBinding(detypedName = "path")
	public String path() {
		return this.path;
	}

	/**
	 * The actual filesystem path. Treated as an absolute path, unless the
	 * 'relative-to' attribute is specified, in which case the value is treated
	 * as relative to that path.
	 * <p>
	 * If treated as an absolute path, the actual runtime pathname specified by
	 * the value of this attribute will be determined as follows:
	 * </p>
	 * If this value is already absolute, then the value is directly used.
	 * Otherwise the runtime pathname is resolved in a system-dependent way. On
	 * UNIX systems, a relative pathname is made absolute by resolving it
	 * against the current user directory. On Microsoft Windows systems, a
	 * relative pathname is made absolute by resolving it against the current
	 * directory of the drive named by the pathname, if any; if not, it is
	 * resolved against the current user directory.
	 */
	@SuppressWarnings("unchecked")
	public T path(String value) {
		Object oldValue = this.path;
		this.path = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("path", oldValue, value);
		return (T) this;
	}

	/**
	 * The name of another previously named path, or of one of the standard
	 * paths provided by the system. If 'relative-to' is provided, the value of
	 * the 'path' attribute is treated as relative to the path specified by this
	 * attribute. The standard paths provided by the system include:
	 * <ul>
	 * <li>jboss.home - the root directory of the JBoss AS distribution</li>
	 * <li>user.home - user's home directory</li>
	 * <li>user.dir - user's current working directory</li>
	 * <li>java.home - java installation directory</li>
	 * <li>jboss.server.base.dir - root directory for an individual server
	 * instance</li>
	 * <li>jboss.server.data.dir - directory the server will use for persistent
	 * data file storage</li>
	 * <li>jboss.server.log.dir - directory the server will use for log file
	 * storage</li>
	 * <li>jboss.server.tmp.dir - directory the server will use for temporary
	 * file storage</li>
	 * <li>jboss.domain.servers.dir - directory under which a host controller
	 * will create the working area for individual server instances</li>
	 * </ul>
	 */
	@ModelNodeBinding(detypedName = "relative-to")
	public String relativeTo() {
		return this.relativeTo;
	}

	/**
	 * The name of another previously named path, or of one of the standard
	 * paths provided by the system. If 'relative-to' is provided, the value of
	 * the 'path' attribute is treated as relative to the path specified by this
	 * attribute. The standard paths provided by the system include:
	 * <ul>
	 * <li>jboss.home - the root directory of the JBoss AS distribution</li>
	 * <li>user.home - user's home directory</li>
	 * <li>user.dir - user's current working directory</li>
	 * <li>java.home - java installation directory</li>
	 * <li>jboss.server.base.dir - root directory for an individual server
	 * instance</li>
	 * <li>jboss.server.data.dir - directory the server will use for persistent
	 * data file storage</li>
	 * <li>jboss.server.log.dir - directory the server will use for log file
	 * storage</li>
	 * <li>jboss.server.tmp.dir - directory the server will use for temporary
	 * file storage</li>
	 * <li>jboss.domain.servers.dir - directory under which a host controller
	 * will create the working area for individual server instances</li>
	 * </ul>
	 */
	@SuppressWarnings("unchecked")
	public T relativeTo(String value) {
		Object oldValue = this.relativeTo;
		this.relativeTo = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("relativeTo", oldValue, value);
		return (T) this;
	}
}
